/*
  Implementierung des Onewire-Protokolls fr 
  DS18x20 auf einem LPCXpresso 1769

  03.10.2011 Jrgen Liegner
  
  aufbauend auf den Vorarbeiten von
  
  Mat Kattanek
  James Harwood
    http://knowledgebase.nxp.com/showthread.php?t=1421
  
  Martin Thomas
  Peter Dannegger
  Colin O'Flynn
    http://gandalf.arubi.uni-kl.de/avr_projects/tempsensor/index.html
*/

#ifndef ONEWIRE_H
  #define ONEWIRE_H

#include "LPC17xx.h"   

typedef union 
{
  uint64_t l;
  uint8_t  b[8];
  struct
    {
    uint8_t crc;
    uint8_t addr[6];
    uint8_t family;
    } s;
} RomType;

typedef enum 
{
  OW_START,
  OW_RESET,
  OW_WRITE,
  OW_READ,
  OW_CMD_COMPLETE,
  OW_NO_DEVICE,
  OW_ERROR
} TOWState;

#define DS18X20_INVALID_DECICELSIUS  2000

#define OW_PORT   2
#define OW_PIN   12 

// Define which timer to use
#define OW_TIMER            3
#define TIMER_IRQ_PRIORIOTY 4

#define POWER_PARASITE

uint8_t  DS18X20_GetStatus();

// Startet die Ermittlung der RomAddresse des DS18x20 
// Es darf nur 1 Sensor am Bus hngen 
// danach ca. 50ms warten oder solange bis
// DS18X20_GetStatus() OW_CMD_COMPLETE liefert
void     DS18X22_StartReadRom();

// sopeicher die ermittelte Addresse auf rom_ptr
uint8_t  DS18X22_GetRom(RomType *rom_ptr);

// Startet eine Messung. Im Parasit-Modus
// braucht der Sensor dafr max. 750ms
void     DS18X22_StartMeasure(RomType *rom_ptr);

// Startet das lesen des Scratchpads
// danach ca. 50ms warten oder solange bis
// DS18X20_GetStatus() OW_CMD_COMPLETE liefert
void     DS18X22_StartReadDecicelsius(RomType *rom_ptr);

// Auswertung des gelesen Wertes.
uint16_t DS18X22_GetDecicelsius(uint8_t familycode);

// initialisiert den Prt und den Timer
void     ow_init();


#endif